/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id: JMSMessageListener.java 4798 2009-08-07 12:30:47Z alitokmen $
 */
package org.ow2.jasmine.monitoring.eos.notification.service.jms;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;

import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.monitoring.eos.common.EventManager;


/**
 * @author Jean-Pierre Poutcheu
 */
public class JMSMessageListener implements MessageListener {

    /**
     * The notification events manager.
     */
    private EventManager<JasmineEventNotification> manager = null;

    /**
     * Constructor of the Message Listener. initialize the manager.
     * @param evManager the event manager
     */
    public JMSMessageListener(final EventManager<JasmineEventNotification> evManager) {
        super();
        this.manager = evManager;
    }

    /**
     * Insert the message event into the manager.
     *
     * @param message the notification event message
     */
    public void onMessage(final Message message) {
        try {
            if (message instanceof ObjectMessage) {

                message.acknowledge();

                ObjectMessage om = (ObjectMessage) message;
                Object jasmineEventNotificationObject = om.getObject();

                if (jasmineEventNotificationObject instanceof JasmineEventNotification) {
                    JasmineEventNotification notification = (JasmineEventNotification) jasmineEventNotificationObject;

                    JasmineEventNotification ev = new JasmineEventNotification();

                    ev.setId(notification.getId());
                    ev.setDate(notification.getDate());
                    ev.setLevel(notification.getLevel());
                    ev.setMessage(notification.getMessage());
                    ev.setRule(notification.getRule());
                    ev.setStatus(notification.getStatus());

                    this.manager.add(ev);
                }
            }

        } catch (Throwable t) {
             System.err.println((t instanceof JMSException) ? "JMSException" : "Throwable" + " Caught in onMessage(): "
                    + t.getMessage());
            t.printStackTrace();
        }
    }
}

